import { areaList } from '@vant/area-data'
// json to array
const json2Array = function (data: Record<string, string>) {
  return Object.keys(data).map(code => ({ code, label: data[code], value: data[code] }))
}

export function useArea() {
  const provinceValue = ref('')
  const cityValue = ref('')

  watch(provinceValue, () => {
    cityValue.value = ''
  })

  const provinceList = ref(
    json2Array(areaList.province_list).sort((a, b) => {
      return a.label.localeCompare(b.label)
    })
  )
  const cityList = computed(() => {
    return json2Array(areaList.city_list)
      .filter(item => {
        const provinceValueCode =
          provinceList.value.find(province => province.label === provinceValue.value)?.code || ''
        return item.code.slice(0, 2) === provinceValueCode.slice(0, 2)
      })
      .sort((a, b) => {
        return a.label.localeCompare(b.label)
      })
  })

  const treeList = json2Array(areaList.province_list).map(item => {
    const children = json2Array(areaList.city_list).filter(item2 => {
      return item2.code.slice(0, 2) === item.code.slice(0, 2)
    })
    return { ...item, children }
  })

  return { provinceValue, cityValue, provinceList, cityList, treeList }
}
